import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/gratuity.dart';

part 'gratuity_api.jretro.dart';

@GenApiClient()
class GratuityApi extends ApiClient with _$GratuityApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    GratuityApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Gratuity
    ///
    /// Create Gratuity
    @PostReq(path: "/gratuity", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Gratuity> createGratuity(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Gratuity body
        ) {
        return super.createGratuity(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Gratuity By ID
    ///
    /// Delete Gratuity By ID
    @DeleteReq(path: "/gratuity/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteGratuityByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteGratuityByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Gratuity List
    ///
    /// Get Gratuity  List
    @GetReq(path: "/gratuity", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Gratuity>> findGratuity(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter, 
        
            @QueryParam("with_deleted") bool withDeleted
        ) {
        return super.findGratuity(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter, 
        
        withDeleted

        ).timeout(timeout);
    }

    /// Get Gratuity By ID
    ///
    /// Get Gratuity By ID
    @GetReq(path: "/gratuity/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Gratuity> getGratuityByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getGratuityByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Gratuity By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/gratuity/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Gratuity> updateGratuityByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Gratuity body
        ) {
        return super.updateGratuityByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
