import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/profile.dart';
import 'package:pointpos_api/model/login.dart';
import 'package:pointpos_api/model/signup.dart';
import 'package:pointpos_api/model/token.dart';
import 'package:pointpos_api/model/change_password.dart';
import 'package:pointpos_api/model/refresh_token.dart';
import 'package:pointpos_api/model/forbidden_exception.dart';
import 'package:pointpos_api/model/update_profile.dart';
import 'package:pointpos_api/model/resend_email_verification.dart';
import 'package:pointpos_api/model/reset_password.dart';
import 'package:pointpos_api/model/internal_server_error_exception.dart';
import 'package:pointpos_api/model/unauthorized_exception.dart';
import 'package:pointpos_api/model/forgot_password.dart';
import 'package:pointpos_api/model/validation_exception.dart';

part 'merchant_api.jretro.dart';

@GenApiClient()
class MerchantApi extends ApiClient with _$MerchantApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    MerchantApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Merchant Change Password
    ///
    /// Merchant Change Password
    @PostReq(path: "/merchant/change-password", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" },  {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Token> changePassword(
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("Authorization") String authorization
            ,
             @AsJson() ChangePassword body
        ) {
        return super.changePassword(
        
        xAPIKey, 
        
        authorization

        ,
        body
        ).timeout(timeout);
    }

    /// Check Reset Token
    ///
    /// Check Reset Token
    @GetReq(path: "/merchant/reset-password/:resetToken", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> checkResetToken(
            @PathParam("resetToken") String resetToken
        ,
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.checkResetToken(
        resetToken
        ,
        xAPIKey

        ).timeout(timeout);
    }

    /// Merchant Forgot Password
    ///
    /// Merchant Forgot Password
    @PostReq(path: "/merchant/forgot-password", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> forgotPassword(
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() ForgotPassword body
        ) {
        return super.forgotPassword(
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Merchant Get Profile
    ///
    /// Merchant Get Profile
    @GetReq(path: "/merchant/profile", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" },  {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Profile> getProfile(
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("Authorization") String authorization
        ) {
        return super.getProfile(
        
        xAPIKey, 
        
        authorization

        ).timeout(timeout);
    }

    /// Merchant Login
    ///
    /// Merchant Login
    @PostReq(path: "/merchant/login", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<Token> login(
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Login body
        ) {
        return super.login(
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Refresh Session
    ///
    /// Refresh Session
    @PostReq(path: "/merchant/refresh-token", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" },  {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Token> refreshToken(
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("Authorization") String authorization
            ,
             @Serialized(MimeTypes.binary) RefreshToken body
        ) {
        return super.refreshToken(
        
        xAPIKey, 
        
        authorization

        ,
        body
        ).timeout(timeout);
    }

    /// Resend Email Verification
    ///
    /// Resend Email Verification
    @PostReq(path: "/merchant/verification", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> resendEmailVerification(
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() ResendEmailVerification body
        ) {
        return super.resendEmailVerification(
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Merchant Reset Password
    ///
    /// Merchant Reset Password
    @PostReq(path: "/merchant/reset-password", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> resetPassword(
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() ResetPassword body
        ) {
        return super.resetPassword(
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Merchant Signup
    ///
    /// Merchant Signup
    @PostReq(path: "/merchant/signup", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> signup(
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Signup body
        ) {
        return super.signup(
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Merchant Update Profile
    ///
    /// Merchant Update Profile
    @PostReq(path: "/merchant/profile", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" },  {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Token> updateProfile(
            
             @AsJson() UpdateProfile body
        ) {
        return super.updateProfile(

        
        body
        ).timeout(timeout);
    }

    /// Email Verification
    ///
    /// Email Verification
    @PostReq(path: "/merchant/verification/:token", metadata: {"auth": [ {"type": "apiKey", "name": "APIKey", "keyName": "X-API-Key", "where": "header" }]})
    Future<void> verification(
            @PathParam("token") String token
        ,
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.verification(
        token
        ,
        xAPIKey

        ).timeout(timeout);
    }


}
