import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/payment_configuration.dart';

part 'payment_configuration_api.jretro.dart';

@GenApiClient()
class PaymentConfigurationApi extends ApiClient with _$PaymentConfigurationApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    PaymentConfigurationApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create PaymentConfiguration
    ///
    /// Create PaymentConfiguration
    @PostReq(path: "/payment-configuration", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PaymentConfiguration> createPaymentConfiguration(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PaymentConfiguration body
        ) {
        return super.createPaymentConfiguration(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete PaymentConfiguration By ID
    ///
    /// Delete PaymentConfiguration By ID
    @DeleteReq(path: "/payment-configuration/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deletePaymentConfigurationByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deletePaymentConfigurationByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get PaymentConfiguration List
    ///
    /// Get PaymentConfiguration  List
    @GetReq(path: "/payment-configuration", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<PaymentConfiguration>> findPaymentConfiguration(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter, 
        
            @QueryParam("with_deleted") bool withDeleted
        ) {
        return super.findPaymentConfiguration(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter, 
        
        withDeleted

        ).timeout(timeout);
    }

    /// Get PaymentConfiguration By ID
    ///
    /// Get PaymentConfiguration By ID
    @GetReq(path: "/payment-configuration/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PaymentConfiguration> getPaymentConfigurationByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getPaymentConfigurationByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update PaymentConfiguration By ID
    ///
    /// Update PaymentConfiguration By ID
    @PutReq(path: "/payment-configuration/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PaymentConfiguration> updatePaymentConfigurationByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PaymentConfiguration body
        ) {
        return super.updatePaymentConfigurationByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
