import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/purchase_order.dart';

part 'purchase_order_api.jretro.dart';

@GenApiClient()
class PurchaseOrderApi extends ApiClient with _$PurchaseOrderApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    PurchaseOrderApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Purchaseorder
    ///
    /// Create Purchaseorder
    @PostReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> createPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.createPurchaseorder(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Purchaseorder By ID
    ///
    /// Delete Purchaseorder By ID
    @DeleteReq(path: "/purchase-order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deletePurchaseorderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deletePurchaseorderByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Purchaseorder List
    ///
    /// Get Purchaseorder  List
    @GetReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<PurchaseOrder>> findPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter, 
        
            @QueryParam("with_deleted") bool withDeleted
        ) {
        return super.findPurchaseorder(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter, 
        
        withDeleted

        ).timeout(timeout);
    }

    /// Get Purchaseorder By ID
    ///
    /// Get Purchaseorder By ID
    @GetReq(path: "/purchase-order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> getPurchaseorderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getPurchaseorderByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Purchaseorder By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/purchase-order/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> updatePurchaseorderByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.updatePurchaseorderByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
