import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/tax.dart';

part 'tax_api.jretro.dart';

@GenApiClient()
class TaxApi extends ApiClient with _$TaxApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    TaxApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Tax
    ///
    /// Create Tax
    @PostReq(path: "/tax", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Tax> createTax(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Tax body
        ) {
        return super.createTax(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Tax By ID
    ///
    /// Delete Tax By ID
    @DeleteReq(path: "/tax/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteTaxByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteTaxByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Tax List
    ///
    /// Get Tax  List
    @GetReq(path: "/tax", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Tax>> findTax(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter, 
        
            @QueryParam("with_deleted") bool withDeleted
        ) {
        return super.findTax(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter, 
        
        withDeleted

        ).timeout(timeout);
    }

    /// Get Tax By ID
    ///
    /// Get Tax By ID
    @GetReq(path: "/tax/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Tax> getTaxByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getTaxByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Tax By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/tax/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Tax> updateTaxByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Tax body
        ) {
        return super.updateTaxByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
