import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/unit.dart';

part 'unit_api.jretro.dart';

@GenApiClient()
class UnitApi extends ApiClient with _$UnitApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    UnitApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Unit
    ///
    /// Create Unit
    @PostReq(path: "/unit", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Unit> createUnit(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Unit body
        ) {
        return super.createUnit(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Unit By ID
    ///
    /// Delete Unit By ID
    @DeleteReq(path: "/unit/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteUnitByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteUnitByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Unit List
    ///
    /// Get Unit  List
    @GetReq(path: "/unit", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Unit>> findUnit(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter, 
        
            @QueryParam("with_deleted") bool withDeleted
        ) {
        return super.findUnit(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter, 
        
        withDeleted

        ).timeout(timeout);
    }

    /// Get Unit By ID
    ///
    /// Get Unit By ID
    @GetReq(path: "/unit/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Unit> getUnitByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getUnitByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Unit By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/unit/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Unit> updateUnitByID(
            @PathParam("id") num id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Unit body
        ) {
        return super.updateUnitByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
